summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvasitem_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvasitem_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qcanvasitem_imp.cpp68
1 files changed, 34 insertions, 34 deletions
diff --git a/kjsembed/qtbindings/qcanvasitem_imp.cpp b/kjsembed/qtbindings/qcanvasitem_imp.cpp
index 9e009567..68c73667 100644
--- a/kjsembed/qtbindings/qcanvasitem_imp.cpp
+++ b/kjsembed/qtbindings/qcanvasitem_imp.cpp
@@ -23,12 +23,12 @@
*/
namespace KJSEmbed {
-TTQCanvasItemImp::TQCanvasItemImp( KJS::ExecState *exec, int mid, bool constructor )
+TQCanvasItemImp::TQCanvasItemImp( KJS::ExecState *exec, int mid, bool constructor )
: JSProxyImp(exec), id(mid), cons(constructor)
{
}
-TTQCanvasItemImp::~TQCanvasItemImp()
+TQCanvasItemImp::~TQCanvasItemImp()
{
}
@@ -43,7 +43,7 @@ void TQCanvasItemImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &obje
};
int idx = 0;
- TTQCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -66,15 +66,15 @@ void TQCanvasItemImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &obje
EnumValue enums[] = {
// enum RttiValues
- { "Rtti_Item", TTQCanvasItem::Rtti_Item },
- { "Rtti_Sprite", TTQCanvasItem::Rtti_Sprite },
- { "Rtti_PolygonalItem", TTQCanvasItem::Rtti_PolygonalItem },
- { "Rtti_Text", TTQCanvasItem::Rtti_Text },
- { "Rtti_Polygon", TTQCanvasItem::Rtti_Polygon },
- { "Rtti_Rectangle", TTQCanvasItem::Rtti_Rectangle },
- { "Rtti_Ellipse", TTQCanvasItem::Rtti_Ellipse },
- { "Rtti_Line", TTQCanvasItem::Rtti_Line },
- { "Rtti_Spline", TTQCanvasItem::Rtti_Spline },
+ { "Rtti_Item", TQCanvasItem::Rtti_Item },
+ { "Rtti_Sprite", TQCanvasItem::Rtti_Sprite },
+ { "Rtti_PolygonalItem", TQCanvasItem::Rtti_PolygonalItem },
+ { "Rtti_Text", TQCanvasItem::Rtti_Text },
+ { "Rtti_Polygon", TQCanvasItem::Rtti_Polygon },
+ { "Rtti_Rectangle", TQCanvasItem::Rtti_Rectangle },
+ { "Rtti_Ellipse", TQCanvasItem::Rtti_Ellipse },
+ { "Rtti_Line", TQCanvasItem::Rtti_Line },
+ { "Rtti_Spline", TQCanvasItem::Rtti_Spline },
{ 0, 0 }
};
@@ -135,7 +135,7 @@ void TQCanvasItemImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- TTQCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -148,28 +148,28 @@ void TQCanvasItemImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
* Extract a TTQCanvasItem pointer from an Object.
*/
-TTQCanvasItem *TQCanvasItemImp::toTQCanvasItem( KJS::Object &self )
+TQCanvasItem *TQCanvasItemImp::toTQCanvasItem( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- TTQObject *obj = ob->object();
+ TQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<TTQCanvasItem *>( obj );
+ return dynamic_cast<TQCanvasItem *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
/*
- if ( !op->inherits(TTQCANVASITEM_OBJECT_NAME_STRING) ) {
+ if ( !op->inherits(TQCANVASITEM_OBJECT_NAME_STRING) ) {
kdDebug() << "Typename of opaque canvas item is " << op->typeName() << endl;
// Check superclasses
return 0;
}
*/
- return op->toNative<TTQCanvasItem>();
+ return op->toNative<TQCanvasItem>();
}
/**
@@ -187,7 +187,7 @@ KJS::Object TQCanvasItemImp::construct( KJS::ExecState *exec, const KJS::List &a
break;
}
- TTQString msg = i18n("TQCanvasItemCons has no constructor with id '%1'.").arg(id);
+ TQString msg = i18n("TQCanvasItemCons has no constructor with id '%1'.").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -197,15 +197,15 @@ KJS::Object TQCanvasItemImp::TQCanvasItem_1( KJS::ExecState *exec, const KJS::Li
#if 0 // This constructor has been disabled by the XSL template
- // Unsupported parameter TTQCanvas *
+ // Unsupported parameter TQCanvas *
return KJS::Object();
- TTQCanvas * arg0; // Dummy
+ TQCanvas * arg0; // Dummy
- // We should now create an instance of the TTQCanvasItem object
+ // We should now create an instance of the TQCanvasItem object
- TTQCanvasItem *ret = new TTQCanvasItem(
+ TQCanvasItem *ret = new TQCanvasItem(
arg0 );
@@ -221,7 +221,7 @@ KJS::Value TQCanvasItemImp::call( KJS::ExecState *exec, KJS::Object &self, const
/*
if ( !instance )
{
- TTQString msg = i18n( "TQCanvasItemImp was not valid" );
+ TQString msg = i18n( "TQCanvasItemImp was not valid" );
return throwError(exec, msg,KJS::ReferenceError);
}
*/
@@ -384,7 +384,7 @@ KJS::Value TQCanvasItemImp::call( KJS::ExecState *exec, KJS::Object &self, const
break;
}
- TTQString msg = i18n( "TQCanvasItemImp has no method with id '%1'." ).arg( id );
+ TQString msg = i18n( "TQCanvasItemImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -565,10 +565,10 @@ KJS::Value TQCanvasItemImp::advance_18( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value TQCanvasItemImp::collidesWith_19( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter const TTQCanvasItem *
return KJS::Value();
- const TTQCanvasItem * arg0; // Dummy
+ const TQCanvasItem * arg0; // Dummy
bool ret;
ret = instance->collidesWith(
@@ -591,10 +591,10 @@ KJS::Value TQCanvasItemImp::collisions_20( KJS::ExecState *exec, KJS::Object &ob
KJS::Value TQCanvasItemImp::setCanvas_21( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter TTQCanvas *
+ // Unsupported parameter TQCanvas *
return KJS::Value();
- TTQCanvas * arg0; // Dummy
+ TQCanvas * arg0; // Dummy
instance->setCanvas(
arg0 );
@@ -605,7 +605,7 @@ KJS::Value TQCanvasItemImp::setCanvas_21( KJS::ExecState *exec, KJS::Object &obj
KJS::Value TQCanvasItemImp::draw_22( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQPainter arg0; // TODO (hack for qcanvas)
+ TQPainter arg0; // TODO (hack for qcanvas)
instance->draw(
arg0 );
@@ -756,7 +756,7 @@ KJS::Value TQCanvasItemImp::rtti_37( KJS::ExecState *exec, KJS::Object &obj, con
KJS::Value TQCanvasItemImp::boundingRect_38( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQRect ret;
+ TQRect ret;
ret = instance->boundingRect( );
return convertToValue( exec, ret );
@@ -765,7 +765,7 @@ KJS::Value TQCanvasItemImp::boundingRect_38( KJS::ExecState *exec, KJS::Object &
KJS::Value TQCanvasItemImp::boundingRectAdvanced_39( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQRect ret;
+ TQRect ret;
ret = instance->boundingRectAdvanced( );
return convertToValue( exec, ret );
@@ -776,7 +776,7 @@ KJS::Value TQCanvasItemImp::canvas_40( KJS::ExecState *exec, KJS::Object &obj, c
{
instance->canvas( );
- return KJS::Value(); // Returns 'TTQCanvas *'
+ return KJS::Value(); // Returns 'TQCanvas *'
}
@@ -148,28 +148,28 @@ void TQCanvasItemImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a TTQCanvasItem pointer from an Object.
+ * Extract a TQCanvasItem pointer from an Object.
*/
@@ -565,10 +565,10 @@ KJS::Value TQCanvasItemImp::advance_18( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value TQCanvasItemImp::collidesWith_19( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter const TTQCanvasItem *
+ // Unsupported parameter const TQCanvasItem *
return KJS::Value();